@@ -31,10 +31,12 @@ from zc.buildout.easy_install import Installer, MissingDistribution
 from distutils.errors import DistutilsError
 
 from collective.releaser import base
+from collective.releaser.base import savewd
 
 join = os.path.join
 
-extract_path = re.compile(r'^((?:htt(?:p|ps)|svn)://)(.*?)/?$')
+extract_path = re.compile(r'^((?:htt(?:p|ps)|svn|file)://)(.*?)/?$')
+is_svn = re.compile(r'^((?:htt(?:p|ps)|svn|file)://)(.*?)/?$') 
 
 def _log(msg):
     print msg
@@ -45,6 +47,7 @@ def _extract_url(url):
     path = extracted[0][1].split('/')
     return protocol, path
 
+@savewd
 def make_release(version=None):
     """this is called when a release is made over a buildout"""
 
@@ -172,14 +175,14 @@ def diff_releases(old=None, new=None, result=None):
     archive_contents(result, tmp)
     # the tarball is create in the folder up `tmp`, let's move it
     topdir = os.path.split(tmp)[0]
-    os.rename(join(topdir, result), join(working_dir, result))
+    shutil.move(join(topdir, result), join(working_dir, result))
     _log('Diff done.')
 
+@savewd
 def archive_contents(archive, location, exclude=None, source=True):
     """generates the tarball"""
     location = os.path.realpath(location)
     # we want a relative storage
-    old_dir = os.getcwd()    
     os.chdir(location)
     dirname, name = os.path.split(location)
     tar = base.TarFile.open(join(dirname, archive), 'w:gz')
@@ -217,7 +220,6 @@ def archive_contents(archive, location, exclude=None, source=True):
                 tar.add(path, arcname, False)
     finally:
         tar.close()
-        os.chdir(old_dir)
 
 def set_option(filename, section, option, value):
     """Setting option."""
@@ -321,6 +323,7 @@ def _make_python(location='.'):
     else:
         return join(location, 'bin', 'python')
 
+@savewd
 def deploy_release(path=None, target=None, archiving='full'):
     """deploy a release in-place"""
     _log('Checking python version ...')
@@ -331,10 +334,12 @@ def deploy_release(path=None, target=None, archiving='full'):
             sys.exit(1)
         path = sys.argv[1]
     url, filename = parse_url(path)
-    if url == '':   # local file
+    if url == '':
+        _log("Using local configuration file %s" % filename)
         target, filename = os.path.split(path)
         release_name = filename.split('.')[0]  
     else:
+        _log("Using network file %s with url %s" % (filename, url))
         folder = url.split('/')[-1]
         release_name = '%s-%s' % (folder, filename.split('.')[0])
         if not target:
@@ -352,15 +357,18 @@ def deploy_release(path=None, target=None, archiving='full'):
     # XXX at this time we are rebuilding everything
     # a pre-built release will have these subdirectories
     # included to avoid compiling again
-    exclude = [join(root, path) for path in 
+    exclude = [join(root, subfolder) for subfolder in 
                ['parts', 'var', 'develop-eggs', 'bin', 'lib',
                 'Lib', 'Scripts', join('downloads', 'dist')]]
-  
+    
+    
     # changes all paths
     if not os.path.isfile(path) and not os.path.isdir(path):
         # let's get the buildout
+        if is_svn.search(path) is None:
+            raise base.ReleaseError('%s is not a svn url' % path) 
         _log(base.system('svn co %s .' % url))
-
+        
     _log('Using local directory %s with %s' % (target, filename))
 
     # let's generate a virtualenv python
@@ -422,7 +430,7 @@ def deploy_release(path=None, target=None, archiving='full'):
     _log('%s ok.' % binary)
 
     # archiving process: changes buildout.cfg and create a tarball
-    old_content = open('buildout.cfg').read()
+    old_content = open(filename).read()
     try:
         if filename != 'buildout.cfg':
             set_option(buildout, 'buildout', 'extends', filename)
@@ -446,7 +454,7 @@ def deploy_release(path=None, target=None, archiving='full'):
         _log('%s ok.' % archive)
     finally:
         # setting back the original buildout.cfg file    
-        f = open('buildout.cfg', 'w')
+        f = open(filename, 'w')
         f.write(old_content)
         f.close()
         # removing MD5
@@ -479,7 +487,7 @@ def copy_archives(from_=None, to=None):
             while os.path.exists(name):
                 name = '%s-%d' % (name, i)
                 i += 1
-            os.rename(target, name)
+            shutil.move(target, name)
                 
         _log('Copying %s to %s' % (source, target))
         os.mkdir(target)
@@ -560,6 +568,7 @@ def console_project_eggs(args=None):
     _log('\n\nEggs collected:')
     _log('\n'.join(['    - %s' % egg for egg in eggs]))
 
+@savewd
 def project_eggs(cfg, tarball=None, filter_eggs=None):
     """Scans for all eggs used by a buildout in eggs, and return their names.
 
@@ -583,15 +592,18 @@ def project_eggs(cfg, tarball=None, filter_eggs=None):
     if buildout_dir == '':
         buildout_dir = os.path.realpath(os.curdir)
 
+    os.chdir(buildout_dir)
+
     def _(lines):
         return [l.strip() 
                 for l in lines.split('\n') if l.strip() != '']
    
     tmp = mkdtemp()
     _log('Working in %s' % tmp)
-
     
     eggs_directory = join(tmp, 'eggs')
+    os.mkdir(eggs_directory) 
+
     install_folder = tmp
     if tarball is None:
         tarball = cfg.split('.')[0]
@@ -605,9 +617,14 @@ def project_eggs(cfg, tarball=None, filter_eggs=None):
     config = ConfigParser.ConfigParser()
     config.read([cfg])
 
+    old_buildout_values = {}
     for name, value in (('eggs-directory', eggs_directory),
                         ('develop-eggs-directory', develop_eggs_directory), 
                         ('download-cache', downloads_directory)):
+        if config.has_option('buildout', name):
+            old_buildout_values[name] = config.get('buildout', name)
+        else:
+            old_buildout_values[name] = None
         config.set('buildout', name, value)
 
     cfg_file = join(tmp, buildout_file)
@@ -735,8 +752,20 @@ def project_eggs(cfg, tarball=None, filter_eggs=None):
     # let's copy the .cfg files as well
     _log('Copying all cfg files')
     for file_ in os.listdir(buildout_dir):
-        if not os.path.splitext(file_) in ('.txt', '.cfg'):
+        if not os.path.splitext(file_)[-1] in ('.txt', '.cfg'):
             continue
+        if file_ == os.path.split(cfg)[-1]:
+            # we need to restore old values from the [buildout]
+            # section
+            config = ConfigParser.ConfigParser()
+            config.read([file_])
+            for key, value in old_buildout_values.items():
+                if value is None and config.has_option('buildout', key):
+                    config.remove_option('buildout', key)
+                if value is not None:
+                    config.set('buildout', key, value)
+            config.write(open(file_, 'w'))
+
         to_ = join(install_folder, file_)
         if os.path.exists(to_):
             os.remove(to_)
@@ -768,7 +797,7 @@ def console_make_svn_structure_for_package(package_directory=None):
 
     tmp_name = "%s_%s" % (package_directory, md5.md5(package_directory).hexdigest())
 
-    os.rename(package_directory, tmp_name)
+    shutil.move(package_directory, tmp_name)
 
     #make the svn structure
     _log("creating %s/tags" % package_directory)
@@ -778,7 +807,7 @@ def console_make_svn_structure_for_package(package_directory=None):
     os.mkdir("%s/branches" % package_directory)
 
     _log("creating %s/trunk" % package_directory)
-    os.rename(tmp_name, "%s/trunk" % package_directory)
+    shutil.move(tmp_name, "%s/trunk" % package_directory)
 
     #svn add and ci it, if the parent directory is a working copy
     try:
